# OpenSCAD Baseline Setup Guide

This guide provides an automated setup process for OpenSCAD and a comprehensive set of commonly used libraries.

## Quick Start: Automated Installation

Run the following command to install OpenSCAD, set up libraries, and validate the configuration:

```bash
curl -sL https://git.nixc.us/colin/OpenSCAD/raw/branch/main/install.sh | bash
```

### What the Script Does

1.	Checks for Homebrew and installs it if not found.
1.	Installs OpenSCAD using Homebrew if it is not already installed.
1.	Creates the OpenSCAD libraries directory if it does not exist.
1.	Clones or updates the following libraries into the OpenSCAD libraries directory:
1.	BOSL2: https://github.com/BelfrySCAD/BOSL2
1.	BOSL: https://github.com/revarbat/BOSL
1.	MCAD: https://github.com/openscad/MCAD
1.	BOLTS: https://github.com/boltsparts/BOLTS
1.	Nuts and Bolts: https://github.com/JohK/nutsnbolts
1.	OpenSCAD Fillets: https://github.com/jfhbrook/openscad-fillets
1.	Shape Library: https://github.com/cznewt/openscad-model-library
1.	OpenSCAD Connectors: https://github.com/kellyegan/OpenSCAD-Arduino-Mounting-Library
1.	BezierScad: https://github.com/chadkirby/BezierScad
1.	Tracklib: https://github.com/joostn/OpenSCAD-Track
1.	Chamfers for OpenSCAD: https://github.com/SebiTimeWaster/Chamfers-for-OpenSCAD
1.	U-Joint Library: https://github.com/celer/openjscad-u-joints
1.	Validates the installation and reports success or failure.

### Verifying the Installation
1.	Open OpenSCAD and create a new file.
1.	Add the following test code:
```
use <BOSL2/std.scad>;

cube([10, 10, 10], center = true);
```

1.	Press F5 (Preview) or F6 (Render). If no errors appear, the installation was successful.

### Troubleshooting
1.	Ensure Homebrew is installed by visiting https://brew.sh/.
1.	Verify Git is installed and accessible by running git --version.
1.	Confirm the libraries exist in the OpenSCAD libraries directory:
```
ls ~/Documents/OpenSCAD/libraries/
```

1.	Verify OpenSCAD is installed by running:
```
openscad --version
```
---

Refer to the documentation or GitHub repositories for additional support or information.